import {EntityRepository, Repository} from "typeorm";
import { ProductDetailsPageCMSEntity } from "./entities/product-details-page-cms.entity";
import { UpdateProductDetailsPageCmsDto } from "./dto/update-product-details-page-cms.dto";
import { CreateProductDetailsPageCmsDto } from "./dto/create-product-details-page-cms.dto";

@EntityRepository(ProductDetailsPageCMSEntity)
export class ProductDetailsPageCmsRepository extends Repository<ProductDetailsPageCMSEntity> {

    async createEntity(dto: CreateProductDetailsPageCmsDto): Promise<ProductDetailsPageCMSEntity | Error> {
        try {
            const entity = this.create({
                productOfferTitle: dto.productOfferTitle,
                relatedProductTitle: dto.relatedProductTitle,
                relatedProductSubtitle: dto.relatedProductSubtitle
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async updateEntity(dto: UpdateProductDetailsPageCmsDto, id: string): Promise<ProductDetailsPageCMSEntity | Error> {
        try {
            await this.update(id, {
                productOfferTitle: dto.productOfferTitle,
                relatedProductTitle: dto.relatedProductTitle,
                relatedProductSubtitle: dto.relatedProductSubtitle
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findAll(): Promise<ProductDetailsPageCMSEntity[] | Error> {
        try {
            return await this.find({
                where: {
                    isDeleted: false
                }
            });
        } catch (e) {
            return e;
        }
    }
}