import {Body, Controller, Delete, Get, Param, Patch, Post, UseGuards} from '@nestjs/common';
import {AdminAuthGuard} from 'src/core/guards/admin-auth.guard';
import {Constants} from 'src/utils/constants';
import {FooterCollectionSectionService} from './footer-collection-section.service';
import {CreateFooterCollectionSectionDto} from './dto/create-footer-collection-section.dto';
import {UpdateFooterCollectionSectionDto} from './dto/update-footer-collection-section.dto';

@Controller({path: 'footer-collection-section', version: Constants.API_VERSION_1})
export class FooterCollectionSectionController {
    constructor(private readonly service: FooterCollectionSectionService) {
    }

    @Post()
    // @UseGuards(AdminAuthGuard)
    create(@Body() dto: CreateFooterCollectionSectionDto) {
        return this.service.create(dto);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(':id')
    @UseGuards(AdminAuthGuard)
    findOne(@Param('id') id: string) {
        return this.service.findOne(id);
    }

    @Patch(':id')
    @UseGuards(AdminAuthGuard)
    update(@Param('id') id: string, @Body() dto: UpdateFooterCollectionSectionDto) {
        return this.service.update(id, dto);
    }

    @Delete(':id')
    @UseGuards(AdminAuthGuard)
    async remove(@Param('id') id: string) {
        return await this.service.remove(id);
    }
}
