import {Body, Controller, Delete, Get, Param, Patch, Post, UseGuards} from '@nestjs/common';
import {AdminAuthGuard} from 'src/core/guards/admin-auth.guard';
import {Constants} from 'src/utils/constants';
import {FooterCompanySectionService} from './footer-company-section.service';
import {CreateFooterCompanySectionDto} from './dto/create-footer-company-section.dto';
import {UpdateFooterCompanySectionDto} from './dto/update-footer-company-section.dto';

@Controller({path: 'footer-company-section', version: Constants.API_VERSION_1})
export class FooterCompanySectionController {
    constructor(private readonly service: FooterCompanySectionService) {
    }

    @Post()
    // @UseGuards(AdminAuthGuard)
    create(@Body() dto: CreateFooterCompanySectionDto) {
        return this.service.create(dto);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(':id')
    @UseGuards(AdminAuthGuard)
    findOne(@Param('id') id: string) {
        return this.service.findOne(id);
    }

    @Patch(':id')
    @UseGuards(AdminAuthGuard)
    update(@Param('id') id: string, @Body() dto: UpdateFooterCompanySectionDto) {
        return this.service.update(id, dto);
    }

    @Delete(':id')
    @UseGuards(AdminAuthGuard)
    async remove(@Param('id') id: string) {
        return await this.service.remove(id);
    }
}
