import {EntityRepository, getConnection, Repository} from "typeorm";
import {CreateFooterCompanySectionDto} from "./dto/create-footer-company-section.dto";
import {UpdateFooterCompanySectionDto} from "./dto/update-footer-company-section.dto";
import {FooterCompanySectionEntity} from "./entity/footer-company-section.entity";

@EntityRepository(FooterCompanySectionEntity)
export class FooterCompanySectionRepository extends Repository<FooterCompanySectionEntity> {

    async createEntity(dto: CreateFooterCompanySectionDto): Promise<FooterCompanySectionEntity | Error> {
        try {
            const {
                sectionText,
                sectionLink
            } = dto;
            const entity = this.create({
                sectionText,
                sectionLink
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<FooterCompanySectionEntity[] | Error> {
        try {
            return await this.find({
                where: {...query, isDeleted: false}
            });
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<FooterCompanySectionEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateFooterCompanySectionDto): Promise<FooterCompanySectionEntity | Error> {
        try {
            await this.update(id, dto);
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(FooterCompanySectionEntity)
                .set({isDeleted: true})
                .where("id = :id", {id: id})
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }

    async countAllQuery(): Promise<any | Error> {
        try {
            return await this.count({
                where: {
                    isDeleted: false
                }
            });
        } catch (e) {
            return e;
        }
    }
}