import {EntityRepository, getConnection, Repository} from "typeorm";
import {FooterCopyrightSectionEntity} from "./entities/footer-copyright-section.entity";
import {CreateFooterCopyrightSectionDto} from "./dto/create-footer-copyright-section.dto";
import {UpdateFooterCopyrightSectionDto} from "./dto/update-footer-copyright-section.dto";

@EntityRepository(FooterCopyrightSectionEntity)
export class FooterCopyrightSectionRepository extends Repository<FooterCopyrightSectionEntity> {
    async createEntity(dto: CreateFooterCopyrightSectionDto): Promise<FooterCopyrightSectionEntity | Error> {
        try {
            const {
                image,
            } = dto;
            const entity = this.create({
                image,
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<FooterCopyrightSectionEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<FooterCopyrightSectionEntity[] | Error> {
        try {
            return await this.find({
                where: {
                    ...query,
                    isDeleted: false
                },
                order: {
                    createdAt: "DESC"
                }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(FooterCopyrightSectionEntity)
                .set({isDeleted: true})
                .where("id = :id", {id: id})
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateFooterCopyrightSectionDto): Promise<FooterCopyrightSectionEntity | Error> {
        try {
            await this.update(id, {
                image: dto.image,
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }
}