import {EntityRepository, getConnection, Repository} from "typeorm";
import {FooterSocialMediaSectionEntity} from "./entities/footer-social-media-section.entity";
import {CreateFooterSocialMediaSectionDto} from "./dto/create-footer-social-media-section.dto";
import {UpdateFooterSocialMediaSectionDto} from "./dto/update-footer-social-media-section.dto";

@EntityRepository(FooterSocialMediaSectionEntity)
export class FooterSocialMediaSectionRepository extends Repository<FooterSocialMediaSectionEntity> {
    async createEntity(dto: CreateFooterSocialMediaSectionDto): Promise<FooterSocialMediaSectionEntity | Error> {
        try {
            const {
                image,
                socialMediaLink,
            } = dto;
            const entity = this.create({
                image,
                socialMediaLink
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<FooterSocialMediaSectionEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<FooterSocialMediaSectionEntity[] | Error> {
        try {
            return await this.find({
                where: {
                    ...query,
                    isDeleted: false
                },
                order: {
                    createdAt: "DESC"
                }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(FooterSocialMediaSectionEntity)
                .set({isDeleted: true})
                .where("id = :id", {id: id})
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateFooterSocialMediaSectionDto): Promise<FooterSocialMediaSectionEntity | Error> {
        try {
            await this.update(id, {
                image: dto.image,
                socialMediaLink: dto.socialMediaLink
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }
}