import { HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';
import { GiftCardRepository } from './gift-card.repository';
import { CreateGiftCardDto } from './dto/create-gift-card.dto';
import { UpdateGiftCardDto } from './dto/update-gift-card.dto';
import { GiftCard } from './entities/gift-card.entity';
import { UploadedMulterFileI } from 'src/modules/SpacesModule/SpacesService';
import { DoSpacesService } from 'src/modules/SpacesModule/SpacesService/doSpacesService';

@Injectable()
export class GiftCardService {
    constructor(
        @InjectRepository(GiftCardRepository)
        private readonly repository: GiftCardRepository,
        private readonly spaceService: DoSpacesService
    ) { }

    async create(
        dto: CreateGiftCardDto,
        files: {
            image: UploadedMulterFileI
        }
    ): Promise<GiftCard | Error> {
        if (files && files.image) {
            const image: any = await this.spaceService.uploadFile(files.image[0], 'GiftCard/');
            dto.image = image;
        }
        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
                Constants.CREATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(201, "Gift Card data created successfully", "data", data);
    }

    async update(
        id: string,
        dto: UpdateGiftCardDto,
        files: {
            image: UploadedMulterFileI
        }
    ): Promise<GiftCard | Error> {
        const res: any = await this.repository.findOneEntity(id);
        if (!res) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }

        if (files && files.image) {
            const image: any = await this.spaceService.uploadFile(files.image[0], 'GiftCard/');
            dto.image = image;
        }

        const data = await this.repository.updateEntity(id, dto);
        if (!data) {
            throw new HttpException(
                Constants.UPDATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(200, "Gift Card data updated successfully", "data", data);
    }

    async findAll(): Promise<GiftCard[] | Error> {
        const data = await this.repository.findByFilterQuery({});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Gift Card data fetched successfully", "data", data);
    }

    async findOne(id: string): Promise<GiftCard[] | Error> {
        const data = await this.repository.findByFilterQuery({ id: id });
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Gift Card data fetched successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Gift Card data deleted successfully");
    }
}
