import { EntityRepository, getConnection, getManager, Repository } from "typeorm";
import { ProductCareVariants } from "./entities/product-care-variants.entity";
import { CreateProductCareVariantsDto } from "./dto/create-product-care-variants.dto";
import { UpdateProductCareVariantsDto } from "./dto/update-product-care-variants.dto";
@EntityRepository(ProductCareVariants)
export class ProductCareVariantsRepository extends Repository<ProductCareVariants> {

    async createEntity(dto: CreateProductCareVariantsDto): Promise<ProductCareVariants | Error> {
        try {
            const { productId, productName, careId, careName } = dto;
            const entity = this.create({
                productId,
                productName,
                careId,
                careName,
            });
            await this.save(entity);
            return entity;
        }
        catch (e) {
            return e;
        }
    }

    async findWithImageByProductId(productId: string): Promise<ProductCareVariants[] | Error> {
        try {
          const sql = `SELECT pcv.*, pc.image as careImage FROM 
          product_care_variants pcv LEFT JOIN product_care pc 
          ON pcv.careId = pc.id WHERE pcv.productId = '${productId}';`;
          const entityManager = getManager();
          return entityManager.query(sql);
        } catch (e) {
          return e;
        }
      }

    async findByFilterQuery(query: any): Promise<ProductCareVariants[] | Error> {
        try {
            return await this.find({
                order: { createdAt: "DESC" },
                where: { ...query, isDeleted: false }
            });
        }
        catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<ProductCareVariants | Error> {
        try {
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateProductCareVariantsDto): Promise<ProductCareVariants | Error> {
        try {
            await this.update(id, dto);
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(ProductCareVariants)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        }
        catch (e) {
            return e;
        }
    }

    async findByName(name: string): Promise<ProductCareVariants[] | Error> {
        try {
            return await this.find({
                where: { 
                    careName: name, 
                    isDeleted: false 
                }
            });
        }
        catch (e) {
            return e;
        }
    }

    async deleteCareVariant(id: any): Promise<any | Error> {
        try {
            const deleteResult = await getConnection()
                .createQueryBuilder()
                .delete()
                .from(ProductCareVariants)
                .where("productId = :productId", { productId: id })
                .execute();
            if (deleteResult.affected > 0) {
                return true;
            }
            return false;
        }
        catch (e) {
            return e;
        }
    }

    async bulkInsertCareVariant(newCare: any): Promise<any | Error> {
        try {
            const insertResult = await getConnection()
                .createQueryBuilder()
                .insert()
                .into(ProductCareVariants)
                .values(newCare)
                .execute();

            if (insertResult.raw.affected > 0) {
                return true;
            }
            return false;
        }
        catch (e) {
            return e;
        }
    }

    async updateProductCareValues(id: any, newCareEntity: any): Promise<any | Error> {
        try {
            const deleteCurrent = await this.deleteCareVariant(id);
            await this.bulkInsertCareVariant(newCareEntity)
        } catch (e) {
            return e;
        }
    }
}