import { EntityRepository, getConnection, getManager, Repository } from "typeorm";
import { CreateProductCategoryDto } from "./dto/create-product-category.dto";
import { UpdateProductCategoryDto } from "./dto/update-product-category.dto";
import { ProductCategory } from "./entities/product-category.entity";

@EntityRepository(ProductCategory)
export class ProductCategoryRepository extends Repository<ProductCategory> {

    async createEntity(dto: CreateProductCategoryDto): Promise<any | Error> {
        try {
            const entity = this.create({
                image: dto.image,
                name: dto.name,
                urlSlug: dto.urlSlug,
                isTrending: dto.isTrending,
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findAll(): Promise<ProductCategory[] | Error> {
        try {
            return await this.find({
                order: {
                    createdAt: -1
                },
                where: {
                    isDeleted: false
                }
            });
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<ProductCategory | Error> {
        try {
            return await this.findOne({
                where: {
                    id: id
                }
            });
        } catch (e) {
            return e;
        }
    }

    async findOneEntityBySlug(urlSlug: string): Promise<ProductCategory[] | Error> {
        try {
            return await this.find({
                where: {
                    urlSlug: urlSlug
                }
            });
        } catch (e) {
            return e;
        }
    }

    async findAllWithProductCount(): Promise<ProductCategory[] | Error> {
        try {
            const sql = `SELECT category.*, COUNT(products.id) AS productCount FROM product_category category 
            LEFT JOIN products ON category.id = products.parentCategoryId AND products.isDeleted = 0 
            AND products.isDeactive = 0 AND products.stock > 0 AND products.price <= 5000
            WHERE category.isDeleted = 0 GROUP BY category.id;`;
            const entityManager = getManager();
            return entityManager.query(sql);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<ProductCategory[] | Error> {
        try {
            return await this.find({
                order: { createdAt: "DESC" },
                where: { ...query, isDeleted: false }
            });
        }
        catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(ProductCategory)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }

    async updateProductCategory(id: string, dto: UpdateProductCategoryDto): Promise<ProductCategory | Error> {
        try {
            await this.update(id, {
                image: dto.image,
                name: dto.name,
                urlSlug: dto.urlSlug,
                isTrending: dto.isTrending,
            });
            return await this.findOne({ where: { id: id } });
        } catch (e) {
            return e;
        }
    }

    async getProductCategoryList(): Promise<ProductCategory[] | Error> {
        try {
            return await this.find({
                where: {
                    isDeleted: false
                },
                order: {
                    createdAt: "DESC"
                },
                take: 3
            });
        } catch (e) {
            return e;
        }
    }

}