import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateProductColorDto } from "./dto/create-product-color.dto";
import { UpdateProductColorDto } from "./dto/update-product-color.dto";
import { ProductColor } from "./entities/product-color.entity";

@EntityRepository(ProductColor)
export class ProductColorRepository extends Repository<ProductColor> {

    async createEntity(dto: CreateProductColorDto): Promise<ProductColor | Error> {
        try {
            const { name, colorCode } = dto;
            const entity = this.create({
                name,
                colorCode
            });
            await this.save(entity);
            return entity;
        }
        catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<ProductColor[] | Error> {
        try {
            return await this.find({
                order: { createdAt: "DESC" },
                where: { ...query, isDeleted: false }
            });
        }
        catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<ProductColor | Error> {
        try {
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateProductColorDto): Promise<ProductColor | Error> {
        try {
            await this.update(id, dto);
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(ProductColor)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        }
        catch (e) {
            return e;
        }
    }

    async findByName(name: string): Promise<ProductColor[] | Error> {
        try {
            return await this.find({
                where: { 
                    name: name, 
                    isDeleted: false 
                }
            });
        }
        catch (e) {
            return e;
        }
    }
}