import { Body, Controller, Delete, Get, Param, Patch, Post, Request, UploadedFile, UploadedFiles, UseInterceptors } from '@nestjs/common';
import { FileInterceptor } from '@nestjs/platform-express';
import { getMulterConfig } from 'src/core/multer.config';
import { Constants } from 'src/utils/constants';
import { ProductDumpImportService } from './product-dump-import.service';
import { FileFieldsInterceptor } from '@nestjs/platform-express';
import { CreateProductDumpImportDto } from './dto/create-product-dump-import.dto';
import { UpdateProductDumpImportDto } from './dto/update-product-dump-import.dto';

@Controller({  
    path: 'product-dump-import',
    version: Constants.API_VERSION_1})
export class ProductDumpImportController {

    constructor(private readonly service : ProductDumpImportService){}

    
    @Post()
    create(@Body() dto: CreateProductDumpImportDto) {
        return this.service.create(dto);
    }

    @Get()
    findAll() {
        return this.service.findAll();
    }

    
    @Get(':id')
    findOne(@Param('id') id: string) {
        return this.service.findOne(id);
    }



    @Patch(':id')
    update(@Param('id') id: string, @Body() dto: UpdateProductDumpImportDto) {
        return this.service.update(id, dto);
    }

    
    @Delete(':id')
    async remove(@Param('id') id: string) {
        return await this.service.remove(id);
    }

}
