import { Body, Controller, Delete, Get, Param, Patch, Post, UseGuards } from '@nestjs/common';
import { AdminAuthGuard } from 'src/core/guards/admin-auth.guard';
import { Constants } from 'src/utils/constants';
import { CreateProductOfferVariantsDto } from './dto/create-product-offer-variants.dto';
import { UpdateProductOfferVariantsDto } from './dto/update-product-offer-variants.dto';
import { ProductOfferVariantsService } from './product-offer-variants.service';

@Controller({ path: 'product-offer-variants', version: Constants.API_VERSION_1 })
export class ProductOfferVariantsController {
    constructor(private readonly service: ProductOfferVariantsService) {}

    @Post()
    @UseGuards(AdminAuthGuard)
    create(@Body() dto: CreateProductOfferVariantsDto) {
        return this.service.create(dto);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(':id')
    @UseGuards(AdminAuthGuard)
    findOne(@Param('id') id: string) {
        return this.service.findOne(id);
    }

    @Patch(':id')
    @UseGuards(AdminAuthGuard)
    update(@Param('id') id: string, @Body() dto: UpdateProductOfferVariantsDto) {
        return this.service.update(id, dto);
    }

    @Delete(':id')
    @UseGuards(AdminAuthGuard)
    async remove(@Param('id') id: string) {
        return await this.service.remove(id);
    }
}
