import { HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';
import { ProductPerksVariantsRepository } from './product-perks-variants.repository';
import { CreateProductPerksVariantsDto } from './dto/create-product-perks-variants.dto';
import { ProductPerksVariantsEntity } from './entities/product-perks-variants.entity';
import { UpdateProductPerksVariantsDto } from './dto/update-product-perks-variants.dto';

@Injectable()
export class ProductPerksVariantsService {
    constructor(
        @InjectRepository(ProductPerksVariantsRepository)
        private readonly repository: ProductPerksVariantsRepository
    ) { }

    async create(dto: CreateProductPerksVariantsDto): Promise<ProductPerksVariantsEntity | Error> {
        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
                Constants.CREATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(201, "Product Perk Variants created successfully", "data", data);
    }

    async findAll(): Promise<ProductPerksVariantsEntity[] | Error> {
        const data = await this.repository.findByFilterQuery({});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Product Perk Variants fetched successfully", "data", data);
    }

    async update(id: string, dto: UpdateProductPerksVariantsDto): Promise<ProductPerksVariantsEntity | Error> {
        const category: any = await this.repository.findOneEntity(id);
        if (!category) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        const data = await this.repository.updateEntity(id, dto);
        if (!data) {
            throw new HttpException(
                Constants.UPDATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(200, "Product Perk Variants updated successfully", "data", data);
    }

    async findOne(id: string): Promise<ProductPerksVariantsEntity[] | Error> {
        const data = await this.repository.findByFilterQuery({ id: id });
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Product Perk Variants fetched successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Product Perk Variants deleted successfully");
    }
}
