import { Body, Controller, Delete, Get, Param, Patch, Post, UseGuards } from '@nestjs/common';
import { AdminAuthGuard } from 'src/core/guards/admin-auth.guard';
import { Constants } from 'src/utils/constants';
import { ProductSizeGuideService } from './product-size-guide.service';
import { CreateProductSizeGuideDto } from './dto/create-product-size-guide.dto';
import { UpdateProductSizeGuideDto } from './dto/update-product-size-guide.dto';
import { AuthGuard } from "src/core/guards/auth.guard";

@Controller({ path: 'product-size-guide', version: Constants.API_VERSION_1 })
export class ProductSizeGuideController {
    constructor(private readonly service: ProductSizeGuideService) {}

    @Post()
    @UseGuards(AdminAuthGuard)
    create(@Body() dto: CreateProductSizeGuideDto) {
        return this.service.create(dto);
    }

    @Get()
    // @UseGuards(AuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(':id')
    @UseGuards(AdminAuthGuard)
    findOne(@Param('id') id: string) {
        return this.service.findOne(id);
    }

    @Get('category/:id')
    findOneByCategory(@Param('id') id: string) {
        return this.service.findOneByCategory(id);
    }

    @Patch(':id')
    @UseGuards(AdminAuthGuard)
    update(@Param('id') id: string, @Body() dto: UpdateProductSizeGuideDto) {
        return this.service.update(id, dto);
    }

    @Delete(':id')
    @UseGuards(AdminAuthGuard)
    async remove(@Param('id') id: string) {
        return await this.service.remove(id);
    }
}
