import {HttpException, HttpStatus, Injectable} from "@nestjs/common";
import {Constants} from "src/utils/constants";
import {CreateProductSizeDto} from "./dto/create-product-size.dto";
import {UpdateProductSizeDto} from "./dto/update-product-size.dto";
import {ProductSize} from "./entities/product-size.entity";
import {ProductSizeRepository} from "./product-size.repository";
import {ResponseUtils} from "src/utils/response.utils";
import {DoSpacesService} from "src/modules/SpacesModule/SpacesService/doSpacesService";
import {urlSlug} from "src/helper/common-helper";

@Injectable()
export class ProductSizeService {
    constructor(
        private readonly repository: ProductSizeRepository,
        private readonly doSpaceService: DoSpacesService
    ) {
    }

    async create(
        dto: CreateProductSizeDto
    ): Promise<any | Error> {
        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
                Constants.CREATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(201, "Size created successfully", "data", data);
    }

    async findAll(): Promise<ProductSize[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Size list fetched successfully", "data", data);
    }

    async findOne(id: string): Promise<any | Error> {
        let data: any = await this.repository.findOneEntity(id);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Size fetched successfully", "data", data);
    }

    async update(
        id: string,
        dto: UpdateProductSizeDto
    ): Promise<ProductSize | Error> {
        const data = await this.repository.updateProductSize(id, dto);
        if (!data) {
            throw new HttpException(
                Constants.UPDATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(200, "Size updated successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Size deleted successfully");
    }
}
